pub struct LogEvent {
pub plugin_id: String,
pub plugin_type: i32,
pub log_level: i32,
pub message: String,
pub details: Vec<Field>,
}Fields
plugin_id: Stringplugin_type: i32log_level: i32message: Stringdetails: Vec<Field>Implementations
Sourceimpl LogEvent
impl LogEvent
Sourcepub fn plugin_type(&self) -> Enum
pub fn plugin_type(&self) -> Enum
Returns the enum value of plugin_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_plugin_type(&mut self, value: Enum)
pub fn set_plugin_type(&mut self, value: Enum)
Sets plugin_type to the provided enum value.
Sourcepub fn log_level(&self) -> Enum
pub fn log_level(&self) -> Enum
Returns the enum value of log_level, or the default if the field is set to an invalid enum value.
Sourcepub fn set_log_level(&mut self, value: Enum)
pub fn set_log_level(&mut self, value: Enum)
Sets log_level to the provided enum value.